@@ -1,8 +1,10 @@
 from multiprocessing import Process, Lock
 from threading import Thread
+from array import array
 import queue
 import copy
 import time
+
 def PoolsFunc(func):
     def wapper(*args:tuple, **kwargs):
         try:
@@ -15,20 +17,14 @@ def PoolsFunc(func):
                 raise Exception('params error.')
             kwargs['handle']= thread_pools
             kwargs['thread-id']= thread_index
-            m_args=[]
-            for offset in range(0,len(args[2])):
-                m_args.append(args[2][offset])
+            if not isinstance(args[2],list):
+                raise Exception("params args must is <list>. you given an <%s>." % type(args[2]).__name__)
+            m_args=args[2]
             while thread_pools._processFlag:
                 if not m_args:
                     break
-                ret= func(tuple(m_args), **kwargs)
-                m_get_args= thread_pools.popArgs()
-                if m_get_args:
-                    m_args=[]
-                    for offset in range(0,len(m_get_args)):
-                        m_args.append(m_get_args[offset])
-                else:
-                    break
+                ret= func(*m_args, **kwargs)
+                m_args= thread_pools.popArgs()
             thread_pools.threadComplete(thread_index)
             return ret
         except Exception as e:
@@ -38,14 +34,14 @@ def PoolsFunc(func):
 class threadPools:
     def __init__(self, threadfunc, daemon=False, isJoin=False, maxSize=10):
         self.Daemon = daemon
-        self.isJoin = isJoin
-        self._processFlag = True
-        self._threadLockArgs = Lock()
-        self._threadLockThreadFunc = Lock()
-        self._threadLockThreadFunc = Lock()
-        self._activeThread = {}
-        self._list = queue.Queue(maxSize)
-        self._args = []
+        self.isJoin = isJoin 
+        self._processFlag = True # 方法状态
+        self.processLock= Lock() # 方法事务锁
+        self._threadLockArgs = Lock() # 任务队列锁
+        self._threadLockThreadFunc = Lock() # 线程队列锁
+        self._activeThread = {} # 活跃线程
+        self._list = queue.Queue(maxSize) # 线程队列
+        self._args = [] # 任务队列
         for offset in range(0, maxSize):
             self._list.put((offset, threadfunc))
 
