@@ -1,12 +1,13 @@
 import json
 import copy
+import random
 from urllib import parse
 from types import FunctionType
 from TDhelper.generic.classDocCfg import doc
 from TDhelper.network.http.REST_HTTP import GET, POST
 from TDhelper.Decorators.log import logging, logging_setup
-
-
+from TDhelper.generic.randGetValue import getValue
+## 以后整理。测试用
 class RPCRegister:
     def __init__(self, serviceConfig, HostConfig, rpcConfig):
         self._serviceConfig = serviceConfig
@@ -14,7 +15,8 @@ class RPCRegister:
         self._access_token = rpcConfig['token']
         self._m_heads = {}
         self._m_heads['api-token'] = self._access_token if self._access_token else ''
-        self._sc_uri = rpcConfig['uri']
+        # rpc uri传数组过来，从数组里随机取一个服务地址。后续需要做负载均衡。
+        self._sc_uri = getValue(rpcConfig['uri']).strip('/')+"/"
 
     def RegisterRPC(self):
         return self._registerService()
@@ -35,7 +37,7 @@ class RPCRegister:
             if m_count < len(self._serviceConfig):
                 m_service_post_data += "&"
         # 注册服务基本信息.
-        state, ret = POST(self._sc_uri+"services/", post_data=bytes(
+        state, ret = POST(self._sc_uri+"services/".strip('/')+"/", post_data=bytes(
             m_service_post_data, encoding='utf-8'), http_headers=self._m_heads, time_out=15)
         if state == 200:
             ret = str(ret, encoding='utf-8')
@@ -70,7 +72,7 @@ class RPCRegister:
                 else:
                     raise Exception(
                         "register hosts {} can't is none." % k)
-            state, ret = POST(self._sc_uri+"hosts/", post_data=bytes(
+            state, ret = POST(self._sc_uri+"hosts/".strip('/')+"/", post_data=bytes(
                 m_service_hosts_post_data, encoding='utf-8'), http_headers=self._m_heads, time_out=15)
             if state != 200:
                 logging.error('register service hosts failed. msg:{}' %
@@ -145,7 +147,7 @@ class RPCRegister:
                                         else:
                                             if m_count < len(methods[i]):
                                                 m_service_uri_post_data += "&"
-                                state, ret = POST(self._sc_uri+"uri/", post_data=bytes(
+                                state, ret = POST(self._sc_uri+"uri/".strip('/')+"/", post_data=bytes(
                                     m_service_uri_post_data, encoding='utf8'), http_headers=self._m_heads, time_out=15)
                                 if state != 200:
                                     logging.error('register service methods failed. msg:{}' % str(
@@ -185,7 +187,7 @@ class RPCRegister:
                                                             except Exception as e:
                                                                 raise e
                                                         state, ret = POST(
-                                                            self._sc_uri+"params/", post_data=bytes(m_service_method_params_post_data, encoding='utf-8'), http_headers=self._m_heads, time_out=15)
+                                                            self._sc_uri+"params/".strip('/')+"/", post_data=bytes(m_service_method_params_post_data, encoding='utf-8'), http_headers=self._m_heads, time_out=15)
                                             # 注册返回值
                                             if 'returns' in methods[i]:
                                                 m_returns = methods[i]['returns']
@@ -207,7 +209,7 @@ class RPCRegister:
                                                             else:
                                                                 if m_count < len(m_returns):
                                                                     reg_returns_params += "&"
-                                                    state, ret = POST(self._sc_uri+"returns/", post_data=bytes(
+                                                    state, ret = POST(self._sc_uri+"returns/".strip('/')+"/", post_data=bytes(
                                                         reg_returns_params, encoding='utf-8'), http_headers=self._m_heads, time_out=15)
                                                     if state == 200:
                                                         ret = json.loads(
@@ -237,7 +239,7 @@ class RPCRegister:
                                                                     m_returns_description += '&valueDescription=' + \
                                                                         parse.quote(
                                                                             m_description)
-                                                                    state, ret = POST(self._sc_uri + "returnDescriptons/", post_data=bytes(
+                                                                    state, ret = POST(self._sc_uri + "returnDescriptons/".strip('/')+"/", post_data=bytes(
                                                                         m_returns_description, encoding='utf-8'), http_headers=self._m_heads, time_out=15)
                                                                     if state != 200:
                                                                         m_msg = 'register return description failed. http code(%d)' % state
@@ -281,11 +283,34 @@ class RPC:
         self._access_token = secret
         self._m_heads = {}
         self._m_heads['api-token'] = self._access_token if self._access_token else ''
-        self._sc_uri = service_center_uri
+        self._sc_uri = getValue(service_center_uri).rstrip('/')+"/"
         self._apisTable = {}
         self._current_service = None
 
+    def RPC_ACCESS(self, entryPoint, access_token, method, **kwargs):
+        method= parse.quote(method)
+        params= ''
+        headers= {}
+        if 'headers' in kwargs:
+            headers= kwargs['headers']
+        headers['api-token']= access_token
+        for o in kwargs:
+            if o.lower()!='headers':
+                params+= o + '=' + kwargs[o]
+        params="?"+params
+        result={"state":False,"msg":''}
+        for uri in entryPoint:
+            uri=uri.rstrip("/")+"/"+method.strip("/")+"/"+params
+            status, body= GET(uri=uri, time_out=15, http_headers= headers)
+            if status == 200:
+                body= json.loads(str(body, encoding='utf-8'))
+                if body['state']==200:
+                    result['state']=True
+                    result['msg']= body['msg']
+                break
+        return result['state'],result['msg']
 
+    
     def _getApi(self, service, method):
         if service+method not in self._apisTable:
             # 远程获取
@@ -304,7 +329,7 @@ class RPC:
         else:
             return False, "can't found %s api." % service+method
 
-    def register(self, service: dict, hosts: [], methods: []):
+    def register(self, service: dict, hosts: list, methods: list):
         '''
             注册服务
             - params:
@@ -534,7 +559,7 @@ class RPC:
         if not self._current_service:
             raise Exception(
                 'service is not set, first call self.handle method to set service.')
-        state, ret = self._getApi(self._current_service, method)
+        state, ret = self._getApi(self._current_service, self._current_service+"."+method)
         if state:
             try:
                 m_uri = ret['uri']
@@ -615,91 +640,4 @@ class RPC:
             except Exception as e:
                 raise e
         else:
-            return {"state": -1, "msg": ret}
-
-
-if __name__ == '__main__':
-    m_rpc = RPC("http://127.0.0.1:8000/api/", "349304398403804983048034")
-    '''
-    print(m_rpc.register(
-        service={"name": "test", "description": "测试添加服务",
-                 "key": "gg", "httpProtocol": "http://"},
-        hosts=[{"host": "127.0.0.1", "port": 8002}, {
-            "host": "192.168.0.100", "port": 8000}],
-        methods=[{"key": "test_method", "uri": "api/uri/", "method": "POST", "version": "1.0.0", "description": "测试添加方法", "params": [{"key": "test_method_p1", "description": "P1参数", "defaultValue": "0"}]}]))
-    #print(m_rpc.call("remote_config","remote_config_register", **{"name":"测试远程配置服务注册","serivce_key":"test_rpc_register"}))
-    '''
-    serviceConfig = {
-        "services": [
-            {
-                # 服务配置
-                "service": {
-                    "name": "TEST",
-                    "description": "TEST",
-                    "key": "TEST",
-                    "accessSecret": "slkjflkjdfejfoejfoefef",
-                    "httpProtocol": "http://"
-                },
-                # 服务器配置
-                "hosts": [
-                    {
-                        "host": "127.0.0.1",
-                        "port": 8004
-                    }
-                ],
-                # 方法配置
-                "methods": [
-                    # 帐号相关 begin
-                    {
-                        "key": "TEST" + "_ACCOUNTS_LIST",
-                        "uri": "api/accounts/",
-                        "method": "GET",
-                        "version": "1.0.0",
-                        "description": "获取帐号列表",
-                        "params": [
-                            {
-                                "key": "page",
-                                "descript": "页码",
-                                "defaultValue": "1"
-                            }
-                        ],
-                        "returns": {
-                            "valueType": "json",
-                            "examples": json.dumps({"state": 200, "msg": {"count": 0, "next": None, "previous": None, "results": []}}),
-                            "descriptions":[
-                                {
-                                    "key": "state",
-                                    "valueDescription": "200:success,\r\n-1:failed."
-                                },
-                                {
-                                    "key": "msg",
-                                    "valueDescription": "success returns json({count:<int>(total records count),next:<string>(next page url),previous:<string>(previous page url),results:[json(<account>)]}),\r\nfailed returns error msg(<string>)."
-                                }
-                            ]
-                        }
-                    }
-                ]
-            }
-        ]
-    }
-    '''
-    count=0
-    for item in serviceConfig["services"]:
-        print(m_rpc.register(
-            service=item['service'],
-            hosts=item['hosts'],
-            methods=item['methods']))
-    '''
-    g = m_rpc.handle("GENERAL_SERVICE")
-    ret = g.call(
-        "GENERAL_SERVICE_VALIDATE_CODE_VALIDATE",
-        **{
-            "validateType": 1,
-            "triggerEvent": "手机验证码登录",
-            "receive": '8615013782894',
-            "code": '22222'
-        })
-    print(ret)
-    #m_id= ret['data']['id']
-    # ret=g.call('REMOTE_CONFIG_CONFIG_REGISTER',**{"config_key":"test1","config_value":"testvalue","service":m_id})
-    # print(ret)
+            return {"state": -1, "msg": ret}
\ No newline at end of file
